stderr = 2;
input_filename = '../meshes/disk.obj';

fprintf( stderr, 'Reading...\n' );
[V,E,F] = read_mesh( input_filename );

fprintf( stderr, 'Building exterior derivatives...\n' );
[d0,d1] = build_exterior_derivatives( V, E, F );

fprintf( stderr, 'Computing circumcenters...\n' );
[c0,c1,c2] = compute_circumcenters( V, d0, d1 );

fprintf( stderr, 'Writing circumcentric subdivision...\n' );
write_circumcentric_subdivision( 'subdivision.ps', d0, d1, c0, c1, c2 );

fprintf( stderr, 'Building Hodge stars...\n' );
[star0,star1,star2] = build_hodge_stars( d0, d1, c0, c1, c2 );

fprintf( stderr, 'Discretizing smooth 1-form...\n' );
omega = discretize_oneform( V, E );
% Some test cases:
% omega = rand(size(E,1),1); % random test case
% omega = d0*rand(size(V,2),1); % curl-free test case
% omega = (star1^-1)*d1'*star2*rand(size(F,1),1); % divergence-free test case
% omega = null( d0*(star0^-1)*d0'*star1 + (star1^-1)*d1'*star2*d1 ); % harmonic test case

fprintf( stderr, 'Decomposing discrete 1-form...\n' );
[ curlfree, divfree, harmonic ] = decompose_oneform( omega, d0, d1, star0, star1, star2 );

M = max( abs( omega ));
fprintf( stderr, 'Interpolating input...\n' );
write_interpolated_vector_field( 'input.ps', omega/M, d0, d1, c0, c1, c2 );
fprintf( stderr, 'Interpolating curl-free component...\n' );
write_interpolated_vector_field( 'curlfree.ps', curlfree/M, d0, d1, c0, c1, c2 );
fprintf( stderr, 'Interpolating divergence-free component...\n' );
write_interpolated_vector_field( 'divfree.ps', divfree/M, d0, d1, c0, c1, c2 );
fprintf( stderr, 'Interpolating harmonic component...\n' );
write_interpolated_vector_field( 'harmonic.ps', harmonic/M, d0, d1, c0, c1, c2 );

disp( 'Done.' );

