  function write_interpolated_vector_field( filename, omega, d0, d1, c0, c1, c2 )
% function write_interpolated_vector_field( filename, omega, d0, d1, c0, c1, c2 )

   fp = fopen( filename, 'w' );

   if( fp == -1 )
      disp( sprintf( 'Error: could not write to file "%s"\n', filename ));
      return;
   end

   nV = size( c0, 2 );
   nE = size( c1, 2 );
   nF = size( c2, 2 );

   scale = max( max(c0) - min(c0));
   newScale = 350.0;
   newMin = [ 50; 180 ];
   c0 = newScale * ( c0 - min( c0' )'*ones(1,nV)) / scale + newMin*ones(1,nV);
   ps_header( fp, [ 0, 0, newScale, newScale ] );

   arrowScale = 500;
   samples = 3;

   % draw several interpolated covectors in each triangle
   for i = 1:nF
      if( mod( i, 20 ) == 0 )
         fprintf( stderr, '   %d percent complete...\r', floor(100*i/nF) );
      end

      edges = find( d1( i, : ));
      v = [ find( d0( edges(1), : )); ...
            find( d0( edges(2), : )); ...
            find( d0( edges(3), : )) ];
      vertices = unique( v );

      for k = 1:3
         if( v( k, 1 ) == vertices( 1 ) && v( k, 2 ) == vertices( 2 )) j1 = k; end
         if( v( k, 1 ) == vertices( 2 ) && v( k, 2 ) == vertices( 3 )) j2 = k; end
         if( v( k, 1 ) == vertices( 1 ) && v( k, 2 ) == vertices( 3 )) j3 = k; end
      end

      alpha = [  omega( edges( j1 )); ...
                 omega( edges( j2 )); ...
                -omega( edges( j3 )) ];
      V = [ c0( :, vertices( 1 )), ...
            c0( :, vertices( 2 )), ...
            c0( :, vertices( 3 )) ];
      A = triangle_area( V(:,1), V(:,2), V(:,3) );

      ps_draw_segment( fp, .1, V(:,1), V(:,2) );
      ps_draw_segment( fp, .1, V(:,2), V(:,3) );
      ps_draw_segment( fp, .1, V(:,3), V(:,1) );

      for ii = 0:samples-1
         for jj = 0:samples-1
            z1 = sqrt(( rand()+ii ) / samples );
            z2 =      ( rand()+jj ) / samples;

            p =      ( 1 - z1 ) * V(:,1) + ...
                z1 * ( 1 - z2 ) * V(:,2) + ...
                        z1 * z2 * V(:,3);

            u = oneform( V, alpha, p );
            p1 = p + u*arrowScale/2;
            p2 = p - u*arrowScale/2;
            ps_draw_segment( fp, 1, p1, p2 );
         end
      end
   end

   fprintf( stderr, '                              \r' );

   fclose( fp );
end

